@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 - 2012 GraphicsMagick Group
+  Copyright (C) 2003 - 2014 GraphicsMagick Group
   Copyright (C) 2002 ImageMagick Studio
   Copyright 1991-1999 E. I. du Pont de Nemours and Company
  
@@ -124,9 +124,7 @@ extern "C" {
 #endif
 typedef unsigned int Quantum;
 #else
-#  ifndef _CH_
-#    error "Specified value of QuantumDepth is not supported"
-#  endif
+#  error "Specified value of QuantumDepth is not supported"
 #endif
 
 #define OpaqueOpacity  0UL
@@ -220,13 +218,24 @@ typedef enum
   SaturateCompositeOp,
   ColorizeCompositeOp,
   LuminizeCompositeOp,
-  ScreenCompositeOp, /* Not yet implemented */
-  OverlayCompositeOp,  /* Not yet implemented */
+  ScreenCompositeOp,
+  OverlayCompositeOp,
   CopyCyanCompositeOp,
   CopyMagentaCompositeOp,
   CopyYellowCompositeOp,
   CopyBlackCompositeOp,
-  DivideCompositeOp
+  DivideCompositeOp,
+  HardLightCompositeOp,
+  ExclusionCompositeOp,
+  ColorDodgeCompositeOp,
+  ColorBurnCompositeOp,
+  SoftLightCompositeOp,
+  LinearBurnCompositeOp,
+  LinearDodgeCompositeOp,
+  LinearLightCompositeOp,
+  VividLightCompositeOp,
+  PinLightCompositeOp,
+  HardMixCompositeOp
 } CompositeOperator;
 
 typedef enum
@@ -382,7 +391,7 @@ typedef enum
 } NoiseType;
 
 /*
-  Image orientation.  Based on TIFF standard values.
+  Image orientation.  Based on TIFF standard values (also EXIF).
 */
 typedef enum               /* Line direction / Frame Direction */
 {                          /* -------------- / --------------- */
@@ -943,7 +952,9 @@ typedef struct _ImageInfo
     *client_data;            /* User-specified data to pass to coder */
 
   FILE
-    *file;                   /* If not null, stdio FILE to read image from */
+    *file;                   /* If not null, stdio FILE * to read image from
+                                (fopen mode "rb") or write image to (fopen
+                                mode "rb+"). */
 
   char
     magick[MaxTextExtent],   /* File format to read. Overrides file extension */
